@@ -161,9 +161,12 @@ class KubeModel(ABC):
 
         job_id = self.args._job_id
         func_id = self.args._func_id
+
+        self.logger.debug("Load optimizer from the database")
+
         weight_key = f'{job_id}:optimizer:{func_id}' 
 
-        if  self._redis_client.exists(weight_key):
+        if  self._redis_client.get(weight_key):
             pickled_val = self._redis_client.get(weight_key)
             opt_states = pickle.loads(pickled_val)  
             self.optimizer.load_state_dict(opt_states)
@@ -210,6 +213,7 @@ class KubeModel(ABC):
         """
         try:
             self.init()
+            # according to the comments, it is nothing to do with the training process.
             self.__save_model()
 
         except RedisError as re:
@@ -227,18 +231,16 @@ class KubeModel(ABC):
         self._set_device()
         self._network.train()
         self._config_optimizer()
-        self.__load_model()
-        self._load_optimizer_redis()
+
 
     def _on_train_end(self):
         """
         Executed after the end of the training loop
         :return:
         """
-        #self.__save_model()
-        self.__save_model()
-        self._save_optimizer_redis()
-        #pass
+        # self.__save_model()
+        # self._save_optimizer_redis()
+        pass
         # self._save_optimizer_state()
 
     def _on_iteration_start(self):
@@ -325,7 +327,7 @@ class KubeModel(ABC):
 
             # load the reference model, train and save
             try:
-                #self._on_iteration_start()
+                self._on_iteration_start()
 
                 for idx, batch in enumerate(loader):
                     # send the batch to the appropriate device
@@ -333,7 +335,7 @@ class KubeModel(ABC):
                     loss += self.train(batch, idx)
                     self.logger.debug(f'loss is {loss}, iterations are {num_iterations}')
 
-                #self._on_iteration_end()
+                self._on_iteration_end()
             except RedisError as re:
                 raise StorageError(re)
             finally:
